IRQHandler

Trait IRQHandler 

pub trait IRQHandler {
    // Required method
    unsafe fn do_prologue();

    // Provided method
    fn get_gate() -> IRQGate { ... }
}
device driver trait that has only prologue

Required Methods

unsafe fn do_prologue()

the “hardirq” part of the irq handler, it must not be interrupted. unsafe: must guarantee the prologue is called with irq disabled the prologue should be short and bounded. It must not block.

Provided Methods

fn get_gate() -> IRQGate

returns an IRQGate to be registered with the plugbox

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors