IRQHandlerEpilogue

Trait IRQHandlerEpilogue 

pub trait IRQHandlerEpilogue {
    // Required methods
    unsafe fn do_prologue();
    unsafe fn do_epilogue();

    // Provided method
    fn get_gate() -> IRQGate { ... }
}
device driver trait with both prologue and epilogue

Required Methods

unsafe fn do_prologue()

same as in IRQHandler

unsafe fn do_epilogue()

the “softirq” part of the irq handler, it allows interrupts but all epilogues must be linearized, therefore an context swap must not happen when there is a running epilogue.

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors